pub enum DeriveTickerData {
Envelope {
timestamp: i64,
instrument_ticker: DeriveTicker,
},
SlimEnvelope {
timestamp: i64,
instrument_ticker: DeriveTickerSnapshot,
},
Ticker(DeriveTicker),
}Expand description
Ticker payload shape pushed by the Derive ticker channels.
Variants
Envelope
Full ticker shape with a feed timestamp and nested ticker snapshot.
Fields
instrument_ticker: DeriveTickerFull instrument ticker snapshot.
SlimEnvelope
Compact ticker shape with a feed timestamp and nested ticker snapshot.
Fields
instrument_ticker: DeriveTickerSnapshotCompact instrument ticker snapshot.
Ticker(DeriveTicker)
Legacy shape where params.data is the ticker object itself.
Implementations
Sourceimpl DeriveTickerData
impl DeriveTickerData
Sourcepub fn instrument_name(&self) -> &Ustr
pub fn instrument_name(&self) -> &Ustr
Returns the ticker instrument name.
Sourcepub fn best_ask_price(&self) -> Decimal
pub fn best_ask_price(&self) -> Decimal
Returns the best ask price.
Sourcepub fn best_bid_price(&self) -> Decimal
pub fn best_bid_price(&self) -> Decimal
Returns the best bid price.
Sourcepub fn best_ask_amount(&self) -> Decimal
pub fn best_ask_amount(&self) -> Decimal
Returns the best ask amount.
Sourcepub fn best_bid_amount(&self) -> Decimal
pub fn best_bid_amount(&self) -> Decimal
Returns the best bid amount.
Sourcepub fn mark_price(&self) -> Decimal
pub fn mark_price(&self) -> Decimal
Returns the current mark price.
Sourcepub fn index_price(&self) -> Decimal
pub fn index_price(&self) -> Decimal
Returns the current index price.
Sourcepub fn funding_rate(&self) -> Option<Decimal>
pub fn funding_rate(&self) -> Option<Decimal>
Returns the current funding rate when the ticker carries one.
Sourcepub fn option_pricing(&self) -> Option<&DeriveOptionPricing>
pub fn option_pricing(&self) -> Option<&DeriveOptionPricing>
Returns option pricing fields when the ticker carries them.
Sourcepub fn stats(&self) -> Option<&DeriveAggregateTradingStats>
pub fn stats(&self) -> Option<&DeriveAggregateTradingStats>
Returns 24-hour aggregate statistics when the ticker carries them.
Sourcepub fn apply_channel_context(&mut self, channel: &str) -> Result<(), String>
pub fn apply_channel_context(&mut self, channel: &str) -> Result<(), String>
Fills compact ticker context that the venue omits from ticker_slim.
Errors
Returns an error when a compact ticker is received on an invalid channel.
Sourcepub fn instrument_id(&self) -> InstrumentId
pub fn instrument_id(&self) -> InstrumentId
Returns the Nautilus instrument ID for this Derive symbol.