pub enum DeriveWsChannel {
TickerSlim {
instrument_name: Ustr,
interval: DeriveTickerInterval,
},
Orderbook {
instrument_name: Ustr,
group: DeriveOrderbookGroup,
depth: DeriveOrderbookDepth,
},
Trades {
instrument_type: DeriveInstrumentType,
currency: Ustr,
},
Orders {
subaccount_id: u64,
},
PrivateTrades {
subaccount_id: u64,
},
Balances {
subaccount_id: u64,
},
Raw(String),
}Expand description
Derive WebSocket subscription channel topic.
Variants
TickerSlim
Public compact ticker channel.
Fields

instrument_name: UstrVenue instrument name.

interval: DeriveTickerIntervalUpdate interval in milliseconds.
Orderbook
Public order book channel.
Fields

instrument_name: UstrVenue instrument name.

group: DeriveOrderbookGroupVenue grouping increment.

depth: DeriveOrderbookDepthRequested depth.
Trades
Public trades channel.
Orders
Private order updates channel.
PrivateTrades
Private trade updates channel.
Balances
Private balance updates channel.
Raw(String)
Passthrough topic for venue channels not yet modeled by the adapter.
Implementations
Sourceimpl DeriveWsChannel
impl DeriveWsChannel
Sourcepub fn ticker_slim(
instrument_name: impl AsRef<str>,
interval: impl AsRef<str>,
) -> Self
pub fn ticker_slim( instrument_name: impl AsRef<str>, interval: impl AsRef<str>, ) -> Self
Returns a compact ticker channel.
Sourcepub fn orderbook(
instrument_name: impl AsRef<str>,
group: impl AsRef<str>,
depth: impl AsRef<str>,
) -> Self
pub fn orderbook( instrument_name: impl AsRef<str>, group: impl AsRef<str>, depth: impl AsRef<str>, ) -> Self
Returns an order book channel.
Sourcepub fn trades(
instrument_type: impl AsRef<str>,
currency: impl AsRef<str>,
) -> Self
pub fn trades( instrument_type: impl AsRef<str>, currency: impl AsRef<str>, ) -> Self
Returns a public trades channel.
Sourcepub const fn private_trades(subaccount_id: u64) -> Self
pub const fn private_trades(subaccount_id: u64) -> Self
Returns a private trades channel.
Sourcepub fn from_topic(topic: impl Into<String>) -> Self
pub fn from_topic(topic: impl Into<String>) -> Self
Parses a topic string into the known channel family when possible.